"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateCypressSetup = void 0;
const devkit_1 = require("@nx/devkit");
function getParameters(options) {
    const files = {
        blank: { elem: 'strong', title: 'Ready to create an app?' },
        list: { elem: 'ion-title', title: 'Inbox' },
        sidemenu: { elem: 'ion-title', title: 'Inbox' },
        tabs: { elem: 'strong', title: 'Tab 1' },
    };
    return files[options.template];
}
function updateCypressSetup(tree, options) {
    if (options.e2eTestRunner !== 'cypress') {
        return;
    }
    updateFiles(tree, options);
}
exports.updateCypressSetup = updateCypressSetup;
function updateFiles(tree, options) {
    const { appsDir } = (0, devkit_1.getWorkspaceLayout)(tree);
    const name = `${options.name}-e2e`;
    const e2eProjectRoot = options.directory
        ? (0, devkit_1.joinPathFragments)(appsDir, (0, devkit_1.names)(options.directory).fileName, name)
        : (0, devkit_1.joinPathFragments)(appsDir, name);
    const { elem, title } = getParameters(options);
    tree.write((0, devkit_1.joinPathFragments)(e2eProjectRoot, 'src/support/app.po.ts'), `export const getGreeting = () => cy.get('${elem}');`);
    const testContent = `
import { getGreeting } from '../support/app.po';

describe('app-blank', () => {
  beforeEach(() => cy.visit('/'));

  it('should display welcome message', () => {
    // Custom command example, see \`../support/commands.ts\` file
    cy.login('my-email@something.com', 'myPassword');

    // Function helper example, see \`../support/app.po.ts\` file
    getGreeting().contains('${title}');
  });
});
  `;
    const testFiles = [
        (0, devkit_1.joinPathFragments)(e2eProjectRoot, 'src/integration/app.spec.ts'),
        (0, devkit_1.joinPathFragments)(e2eProjectRoot, 'src/e2e/app.cy.ts'),
    ];
    for (const testFile of testFiles) {
        if (tree.exists(testFile)) {
            tree.write(testFile, testContent);
        }
    }
}
//# sourceMappingURL=update-cypress-setup.js.map